@@ -3,5 +3,5 @@ from .fun_captcha import FuncaptchaTask
 from .recaptcha_v3 import RecaptchaV3Task
 from .hcaptcha import HCaptchaTask
 from .image_to_text import ImageToTextTask
-from .gee_test import GeeTestTask
+from .geetest import GeeTestTask
 from .utils import CapmonsterException
